@@ -73,11 +73,17 @@ circumference2
 
 square_pyramid
     A function that calculates the volume of a square based pyramid
-"""
 
+lcm
+    A function that calculates the Lowest Common Multiple from 2 numbers
+
+lcm_3_nums
+    A function that calculates the Lowest Common Multiple from 3 numbers
+"""
 from .circle import *
 from .physics import *
 from .pythagorus import *
 from .trapezium import *
 from .triangle import *
 from .pyramid import *
+from .lcm import *
